#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/cron-update.sh - update or generate new cron configuration
#
# Creation:     2005-05-21  max
# Last Update:  $Id: cron-update.sh 41390 2016-05-07 17:16:41Z hbfl $
#
# Copyright (c) 2001-2016 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name='cron'

# include configib
. /var/install/include/configlib

# ---------------------------------------------------------------------------
# set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_CRON='yes'

    CRON_N='1'

    CRON_1_NAME=''
    CRON_1_ACTIVE='yes'
    CRON_1_TIMES='0 0-23/2 * * *'
    CRON_1_COMMAND='/etc/cron.daily/logrotate'
}

# ---------------------------------------------------------------------------
# read old configuration
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}

    {
    #------------------------------------------------------------------------
    printgpl --conf ${package_name} '2005-03-04' 'max'
    #------------------------------------------------------------------------

    #------------------------------------------------------------------------
    printgroup 'Cron Jobs'
    #------------------------------------------------------------------------

    printvar 'START_CRON'
    printcomment            'start cron: yes or no'
    echo

    printvar 'CRON_N'
    printcomment                'number of cron jobs to add'

    idx=1
    while [ ${idx} -le ${CRON_N} ]
    do
        eval active='${CRON_'${idx}'_ACTIVE}'

        case x${active} in
        x)
            eval CRON_${idx}_ACTIVE="yes"
            ;;
        x*)
            : # nothing to do
            ;;
        esac

        echo
        printvar "CRON_${idx}_NAME"
        printcomment        "Use a name what ever you want, it's only for you"

        printvar "CRON_${idx}_ACTIVE"
        printcomment        'Use yes or no'

        printvar "CRON_${idx}_TIMES"
        printcomment        'Cron configuration string'

        printvar "CRON_${idx}_COMMAND"
        printcomment        'Command to start with cron'

        idx=$(/usr/bin/expr ${idx} + 1)
    done
    #------------------------------------------------------------------------
    printend
    #------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}

}
# ---------------------------------------------------------------------------
# create check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} "2005-03-04" "max" >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable          OPT_VARIABLE        VARIABLE_N    VALUE
START_CRON          -                   -             YESNO

CRON_N              START_CRON          -             NUMERIC
CRON_%_NAME         START_CRON          CRON_N        NONE
CRON_%_ACTIVE       START_CRON          CRON_N        YESNO
CRON_%_TIMES        CRON_%_ACTIVE       CRON_N        CRONTAB
CRON_%_COMMAND      CRON_%_ACTIVE       CRON_N        NONE

EOF

    # Set rights for check file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}
}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
